# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_price_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'v1/rules/delivery_price_warehouse.proto\x12\x32pro.omni.oms.api.v1.rules.delivery_price_warehouse\x1a\x11\x63ommon/base.proto"\xbb\x01\n\x16\x44\x65liveryPriceWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x19\n\x11\x64\x65livery_price_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa3\x01\n#DeliveryPriceWarehouseCreateRequest\x12\x19\n\x11\x64\x65livery_price_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdf\x01\n$DeliveryPriceWarehouseCreateResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xff\x02\n!DeliveryPriceWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x98\x02\n"DeliveryPriceWarehouseReadResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x03(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcb\x01\n#DeliveryPriceWarehouseUpdateRequest\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdf\x01\n$DeliveryPriceWarehouseUpdateResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"i\n#DeliveryPriceWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"q\n$DeliveryPriceWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf1\x06\n\x1d\x44\x65liveryPriceWarehouseService\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseCreate\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseCreateRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseCreateResponse"\x00\x12\xcd\x01\n\x1a\x44\x65liveryPriceWarehouseRead\x12U.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseReadRequest\x1aV.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseReadResponse"\x00\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseUpdate\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseUpdateRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseUpdateResponse"\x00\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseDelete\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseDeleteRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_price_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYPRICEWAREHOUSE"]._serialized_start = 115
    _globals["_DELIVERYPRICEWAREHOUSE"]._serialized_end = 302
    _globals["_DELIVERYPRICEWAREHOUSECREATEREQUEST"]._serialized_start = 305
    _globals["_DELIVERYPRICEWAREHOUSECREATEREQUEST"]._serialized_end = 468
    _globals["_DELIVERYPRICEWAREHOUSECREATERESPONSE"]._serialized_start = 471
    _globals["_DELIVERYPRICEWAREHOUSECREATERESPONSE"]._serialized_end = 694
    _globals["_DELIVERYPRICEWAREHOUSEREADREQUEST"]._serialized_start = 697
    _globals["_DELIVERYPRICEWAREHOUSEREADREQUEST"]._serialized_end = 1080
    _globals["_DELIVERYPRICEWAREHOUSEREADRESPONSE"]._serialized_start = 1083
    _globals["_DELIVERYPRICEWAREHOUSEREADRESPONSE"]._serialized_end = 1363
    _globals["_DELIVERYPRICEWAREHOUSEUPDATEREQUEST"]._serialized_start = 1366
    _globals["_DELIVERYPRICEWAREHOUSEUPDATEREQUEST"]._serialized_end = 1569
    _globals["_DELIVERYPRICEWAREHOUSEUPDATERESPONSE"]._serialized_start = 1572
    _globals["_DELIVERYPRICEWAREHOUSEUPDATERESPONSE"]._serialized_end = 1795
    _globals["_DELIVERYPRICEWAREHOUSEDELETEREQUEST"]._serialized_start = 1797
    _globals["_DELIVERYPRICEWAREHOUSEDELETEREQUEST"]._serialized_end = 1902
    _globals["_DELIVERYPRICEWAREHOUSEDELETERESPONSE"]._serialized_start = 1904
    _globals["_DELIVERYPRICEWAREHOUSEDELETERESPONSE"]._serialized_end = 2017
    _globals["_DELIVERYPRICEWAREHOUSESERVICE"]._serialized_start = 2020
    _globals["_DELIVERYPRICEWAREHOUSESERVICE"]._serialized_end = 2901
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/transition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import flow_pb2 as v1_dot_sales_dot_flow__pb2
from omni.pro.protos.v1.sales import state_pb2 as v1_dot_sales_dot_state__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/sales/transition.proto\x12$pro.omni.oms.api.v1.sales.transition\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14v1/sales/state.proto\x1a\x13v1/sales/flow.proto"\x84\x03\n\nTransition\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x32\n\x04\x66low\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.flow.Flow\x12<\n\x0csource_state\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12\x41\n\x11\x64\x65stination_state\x18\x04 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12\x0f\n\x07trigger\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\r\n\x05logic\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe3\x01\n\x17TransitionCreateRequest\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\x05\x12\x17\n\x0fsource_state_id\x18\x02 \x01(\x05\x12\x1c\n\x14\x64\x65stination_state_id\x18\x03 \x01(\x05\x12\x0f\n\x07trigger\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\r\n\x05logic\x18\x06 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xab\x01\n\x18TransitionCreateResponse\x12\x44\n\ntransition\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.sales.transition.Transition\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf3\x02\n\x15TransitionReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe5\x01\n\x16TransitionReadResponse\x12\x45\n\x0btransitions\x18\x01 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.sales.transition.Transition\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x97\x01\n\x17TransitionUpdateRequest\x12\x44\n\ntransition\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.sales.transition.Transition\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xab\x01\n\x18TransitionUpdateResponse\x12\x44\n\ntransition\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.sales.transition.Transition\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"]\n\x17TransitionDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"e\n\x18TransitionDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe5\x04\n\x11TransitionService\x12\x93\x01\n\x10TransitionCreate\x12=.pro.omni.oms.api.v1.sales.transition.TransitionCreateRequest\x1a>.pro.omni.oms.api.v1.sales.transition.TransitionCreateResponse"\x00\x12\x8d\x01\n\x0eTransitionRead\x12;.pro.omni.oms.api.v1.sales.transition.TransitionReadRequest\x1a<.pro.omni.oms.api.v1.sales.transition.TransitionReadResponse"\x00\x12\x93\x01\n\x10TransitionUpdate\x12=.pro.omni.oms.api.v1.sales.transition.TransitionUpdateRequest\x1a>.pro.omni.oms.api.v1.sales.transition.TransitionUpdateResponse"\x00\x12\x93\x01\n\x10TransitionDelete\x12=.pro.omni.oms.api.v1.sales.transition.TransitionDeleteRequest\x1a>.pro.omni.oms.api.v1.sales.transition.TransitionDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.transition_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TRANSITION"]._serialized_start = 162
    _globals["_TRANSITION"]._serialized_end = 550
    _globals["_TRANSITIONCREATEREQUEST"]._serialized_start = 553
    _globals["_TRANSITIONCREATEREQUEST"]._serialized_end = 780
    _globals["_TRANSITIONCREATERESPONSE"]._serialized_start = 783
    _globals["_TRANSITIONCREATERESPONSE"]._serialized_end = 954
    _globals["_TRANSITIONREADREQUEST"]._serialized_start = 957
    _globals["_TRANSITIONREADREQUEST"]._serialized_end = 1328
    _globals["_TRANSITIONREADRESPONSE"]._serialized_start = 1331
    _globals["_TRANSITIONREADRESPONSE"]._serialized_end = 1560
    _globals["_TRANSITIONUPDATEREQUEST"]._serialized_start = 1563
    _globals["_TRANSITIONUPDATEREQUEST"]._serialized_end = 1714
    _globals["_TRANSITIONUPDATERESPONSE"]._serialized_start = 1717
    _globals["_TRANSITIONUPDATERESPONSE"]._serialized_end = 1888
    _globals["_TRANSITIONDELETEREQUEST"]._serialized_start = 1890
    _globals["_TRANSITIONDELETEREQUEST"]._serialized_end = 1983
    _globals["_TRANSITIONDELETERESPONSE"]._serialized_start = 1985
    _globals["_TRANSITIONDELETERESPONSE"]._serialized_end = 2086
    _globals["_TRANSITIONSERVICE"]._serialized_start = 2089
    _globals["_TRANSITIONSERVICE"]._serialized_end = 2702
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_time_warehouse_pb2 as v1_dot_rules_dot_delivery__time__warehouse__pb2


class DeliveryTimeWarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryTimeWarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseCreate",
            request_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateResponse.FromString,
        )
        self.DeliveryTimeWarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseRead",
            request_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadResponse.FromString,
        )
        self.DeliveryTimeWarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseUpdate",
            request_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateResponse.FromString,
        )
        self.DeliveryTimeWarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseDelete",
            request_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteResponse.FromString,
        )


class DeliveryTimeWarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryTimeWarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeWarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeWarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeWarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryTimeWarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryTimeWarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeWarehouseCreate,
            request_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateResponse.SerializeToString,
        ),
        "DeliveryTimeWarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeWarehouseRead,
            request_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadResponse.SerializeToString,
        ),
        "DeliveryTimeWarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeWarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateResponse.SerializeToString,
        ),
        "DeliveryTimeWarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeWarehouseDelete,
            request_deserializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryTimeWarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryTimeWarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseCreate",
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeWarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseRead",
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeWarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseUpdate",
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeWarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseService/DeliveryTimeWarehouseDelete",
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__warehouse__pb2.DeliveryTimeWarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/territory_matrix_value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)v1/utilities/territory_matrix_value.proto\x12\x34pro.omni.oms.api.v1.utilities.territory_matrix_value\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x86\x02\n\x14TerritoryMatrixValue\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x12territory_matrixes\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xfb\x01\n\x1eTerritoryMatrixValueAddRequest\x12\x36\n\x12territory_matrixes\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd8\x01\n\x1fTerritoryMatrixValueAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12j\n\x16territory_matrix_value\x18\x02 \x01(\x0b\x32J.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValue"\xfd\x02\n\x1fTerritoryMatrixValueReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x02\n TerritoryMatrixValueReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12m\n\x19territory_matrixes_values\x18\x03 \x03(\x0b\x32J.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValue"\xc7\x01\n!TerritoryMatrixValueUpdateRequest\x12j\n\x16territory_matrix_value\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValue\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdb\x01\n"TerritoryMatrixValueUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12j\n\x16territory_matrix_value\x18\x02 \x01(\x0b\x32J.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValue"g\n!TerritoryMatrixValueDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"o\n"TerritoryMatrixValueDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xde\x06\n\x1bTerritoryMatrixValueService\x12\xc8\x01\n\x17TerritoryMatrixValueAdd\x12T.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueAddRequest\x1aU.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueAddResponse"\x00\x12\xcb\x01\n\x18TerritoryMatrixValueRead\x12U.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueReadRequest\x1aV.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueReadResponse"\x00\x12\xd1\x01\n\x1aTerritoryMatrixValueUpdate\x12W.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueUpdateRequest\x1aX.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueUpdateResponse"\x00\x12\xd1\x01\n\x1aTerritoryMatrixValueDelete\x12W.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueDeleteRequest\x1aX.pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.territory_matrix_value_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TERRITORYMATRIXVALUE"]._serialized_start = 181
    _globals["_TERRITORYMATRIXVALUE"]._serialized_end = 443
    _globals["_TERRITORYMATRIXVALUEADDREQUEST"]._serialized_start = 446
    _globals["_TERRITORYMATRIXVALUEADDREQUEST"]._serialized_end = 697
    _globals["_TERRITORYMATRIXVALUEADDRESPONSE"]._serialized_start = 700
    _globals["_TERRITORYMATRIXVALUEADDRESPONSE"]._serialized_end = 916
    _globals["_TERRITORYMATRIXVALUEREADREQUEST"]._serialized_start = 919
    _globals["_TERRITORYMATRIXVALUEREADREQUEST"]._serialized_end = 1300
    _globals["_TERRITORYMATRIXVALUEREADRESPONSE"]._serialized_start = 1303
    _globals["_TERRITORYMATRIXVALUEREADRESPONSE"]._serialized_end = 1582
    _globals["_TERRITORYMATRIXVALUEUPDATEREQUEST"]._serialized_start = 1585
    _globals["_TERRITORYMATRIXVALUEUPDATEREQUEST"]._serialized_end = 1784
    _globals["_TERRITORYMATRIXVALUEUPDATERESPONSE"]._serialized_start = 1787
    _globals["_TERRITORYMATRIXVALUEUPDATERESPONSE"]._serialized_end = 2006
    _globals["_TERRITORYMATRIXVALUEDELETEREQUEST"]._serialized_start = 2008
    _globals["_TERRITORYMATRIXVALUEDELETEREQUEST"]._serialized_end = 2111
    _globals["_TERRITORYMATRIXVALUEDELETERESPONSE"]._serialized_start = 2113
    _globals["_TERRITORYMATRIXVALUEDELETERESPONSE"]._serialized_end = 2224
    _globals["_TERRITORYMATRIXVALUESERVICE"]._serialized_start = 2227
    _globals["_TERRITORYMATRIXVALUESERVICE"]._serialized_end = 3089
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.sales import client_pb2 as _client_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Address(_message.Message):
    __slots__ = [
        "id",
        "client",
        "address_doc_id",
        "address_code",
        "code",
        "name",
        "active",
        "external_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    client: _client_pb2.Client
    address_doc_id: str
    address_code: str
    code: str
    name: str
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...,
        address_doc_id: _Optional[str] = ...,
        address_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class AddressCreateRequest(_message.Message):
    __slots__ = ["client_id", "address_doc_id", "address_code", "code", "name", "external_id", "context"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client_id: int
    address_doc_id: str
    address_code: str
    code: str
    name: str
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        client_id: _Optional[int] = ...,
        address_doc_id: _Optional[str] = ...,
        address_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressCreateResponse(_message.Message):
    __slots__ = ["address", "response_standard"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    address: Address
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        address: _Optional[_Union[Address, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class AddressReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressReadResponse(_message.Message):
    __slots__ = ["addresses", "meta_data", "response_standard"]
    ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    addresses: _containers.RepeatedCompositeFieldContainer[Address]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        addresses: _Optional[_Iterable[_Union[Address, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class AddressUpdateRequest(_message.Message):
    __slots__ = ["address", "context"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    address: Address
    context: _base_pb2.Context
    def __init__(
        self,
        address: _Optional[_Union[Address, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressUpdateResponse(_message.Message):
    __slots__ = ["address", "response_standard"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    address: Address
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        address: _Optional[_Union[Address, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class AddressDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class AddressDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/compute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/rules/compute.proto\x12!pro.omni.oms.api.v1.rules.compute\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xfc\x01\n\x07\x43ompute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_request\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61ta_process\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_internal\x18\x04 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_external\x18\x05 \x01(\t\x12\x0c\n\x04time\x18\x06 \x01(\x02\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc8\x01\n\x14\x43omputeCreateRequest\x12\x14\n\x0c\x64\x61ta_request\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_process\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_internal\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_external\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"\xf0\x02\n\x12\x43omputeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd8\x01\n\x13\x43omputeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12;\n\x07\x63ompute\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"\x8b\x01\n\x14\x43omputeUpdateRequest\x12;\n\x07\x63ompute\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"Z\n\x14\x43omputeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute2\xa5\x04\n\x0e\x43omputeService\x12\x84\x01\n\rComputeCreate\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeCreateRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeCreateResponse"\x00\x12~\n\x0b\x43omputeRead\x12\x35.pro.omni.oms.api.v1.rules.compute.ComputeReadRequest\x1a\x36.pro.omni.oms.api.v1.rules.compute.ComputeReadResponse"\x00\x12\x84\x01\n\rComputeUpdate\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeUpdateRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeUpdateResponse"\x00\x12\x84\x01\n\rComputeDelete\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeDeleteRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.compute_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_COMPUTE"]._serialized_start = 113
    _globals["_COMPUTE"]._serialized_end = 365
    _globals["_COMPUTECREATEREQUEST"]._serialized_start = 368
    _globals["_COMPUTECREATEREQUEST"]._serialized_end = 568
    _globals["_COMPUTECREATERESPONSE"]._serialized_start = 571
    _globals["_COMPUTECREATERESPONSE"]._serialized_end = 730
    _globals["_COMPUTEREADREQUEST"]._serialized_start = 733
    _globals["_COMPUTEREADREQUEST"]._serialized_end = 1101
    _globals["_COMPUTEREADRESPONSE"]._serialized_start = 1104
    _globals["_COMPUTEREADRESPONSE"]._serialized_end = 1320
    _globals["_COMPUTEUPDATEREQUEST"]._serialized_start = 1323
    _globals["_COMPUTEUPDATEREQUEST"]._serialized_end = 1462
    _globals["_COMPUTEUPDATERESPONSE"]._serialized_start = 1465
    _globals["_COMPUTEUPDATERESPONSE"]._serialized_end = 1624
    _globals["_COMPUTEDELETEREQUEST"]._serialized_start = 1626
    _globals["_COMPUTEDELETEREQUEST"]._serialized_end = 1716
    _globals["_COMPUTEDELETERESPONSE"]._serialized_start = 1719
    _globals["_COMPUTEDELETERESPONSE"]._serialized_end = 1878
    _globals["_COMPUTESERVICE"]._serialized_start = 1881
    _globals["_COMPUTESERVICE"]._serialized_end = 2430
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.catalogs import family_pb2 as _family_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ProductTemplate(_message.Message):
    __slots__ = ["id", "code", "name", "family", "attribute_values", "external_id", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VALUES_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    code: str
    name: str
    family: _family_pb2.Family
    attribute_values: _struct_pb2.Struct
    external_id: str
    active: _wrappers_pb2.BoolValue
    def __init__(
        self,
        id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        family: _Optional[_Union[_family_pb2.Family, _Mapping]] = ...,
        attribute_values: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateCreateRequest(_message.Message):
    __slots__ = ["code", "name", "family_id", "attribute_values", "external_id", "context"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VALUES_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    family_id: str
    attribute_values: _struct_pb2.Struct
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        family_id: _Optional[str] = ...,
        attribute_values: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateCreateResponse(_message.Message):
    __slots__ = ["response_standard", "product_template"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product_template: ProductTemplate
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product_template: _Optional[_Union[ProductTemplate, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateReadResponse(_message.Message):
    __slots__ = ["response_standard", "product_templates", "meta_data"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product_templates: _containers.RepeatedCompositeFieldContainer[ProductTemplate]
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product_templates: _Optional[_Iterable[_Union[ProductTemplate, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateUpdateRequest(_message.Message):
    __slots__ = ["product_template", "context"]
    PRODUCT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    product_template: ProductTemplate
    context: _base_pb2.Context
    def __init__(
        self,
        product_template: _Optional[_Union[ProductTemplate, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "product_template"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product_template: ProductTemplate
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product_template: _Optional[_Union[ProductTemplate, _Mapping]] = ...,
    ) -> None: ...

class ProductTemplateDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ProductTemplateDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class Product(_message.Message):
    __slots__ = ["id", "code", "name", "product_template_id", "attribute_values", "external_id", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VALUES_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    code: str
    name: str
    product_template_id: str
    attribute_values: _struct_pb2.Struct
    external_id: str
    active: _wrappers_pb2.BoolValue
    def __init__(
        self,
        id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        product_template_id: _Optional[str] = ...,
        attribute_values: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
    ) -> None: ...

class ProductCreateRequest(_message.Message):
    __slots__ = ["code", "name", "product_template_id", "attribute_values", "external_id", "context"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VALUES_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    product_template_id: str
    attribute_values: _struct_pb2.Struct
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        product_template_id: _Optional[str] = ...,
        attribute_values: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductCreateResponse(_message.Message):
    __slots__ = ["response_standard", "product"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product: Product
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product: _Optional[_Union[Product, _Mapping]] = ...,
    ) -> None: ...

class ProductReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductReadResponse(_message.Message):
    __slots__ = ["response_standard", "products", "meta_data"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCTS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    products: _containers.RepeatedCompositeFieldContainer[Product]
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        products: _Optional[_Iterable[_Union[Product, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class ProductUpdateRequest(_message.Message):
    __slots__ = ["product", "context"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    product: Product
    context: _base_pb2.Context
    def __init__(
        self,
        product: _Optional[_Union[Product, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "product"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product: Product
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product: _Optional[_Union[Product, _Mapping]] = ...,
    ) -> None: ...

class ProductDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ProductDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ProductAll(_message.Message):
    __slots__ = ["id", "code", "name", "type", "img_url", "product_template_id", "product_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    IMG_URL_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    code: str
    name: str
    type: str
    img_url: str
    product_template_id: str
    product_id: str
    def __init__(
        self,
        id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type: _Optional[str] = ...,
        img_url: _Optional[str] = ...,
        product_template_id: _Optional[str] = ...,
        product_id: _Optional[str] = ...,
    ) -> None: ...

class ProductAllReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductAllReadResponse(_message.Message):
    __slots__ = ["response_standard", "product_all", "meta_data"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ALL_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product_all: _containers.RepeatedCompositeFieldContainer[ProductAll]
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product_all: _Optional[_Iterable[_Union[ProductAll, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/upload_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/utilities/upload_file.proto\x12)pro.omni.oms.api.v1.utilities.upload_file\x1a\x11\x63ommon/base.proto"\x84\x01\n\x05\x46ield\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x17\n\x0fx_amz_algorithm\x18\x02 \x01(\t\x12\x18\n\x10x_amz_credential\x18\x03 \x01(\t\x12\x12\n\nx_amz_date\x18\x04 \x01(\t\x12\x0e\n\x06policy\x18\x05 \x01(\t\x12\x17\n\x0fx_amz_signature\x18\x06 \x01(\t"[\n\nUploadFile\x12\x0b\n\x03url\x18\x01 \x01(\t\x12@\n\x06\x66ields\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.upload_file.Field"^\n\x11UploadXlsxRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa6\x01\n\x12UploadXlsxResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x45\n\x06result\x18\x02 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.utilities.upload_file.UploadFile2\xa1\x01\n\x11UploadFileService\x12\x8b\x01\n\nUploadXlsx\x12<.pro.omni.oms.api.v1.utilities.upload_file.UploadXlsxRequest\x1a=.pro.omni.oms.api.v1.utilities.upload_file.UploadXlsxResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.upload_file_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_FIELD"]._serialized_start = 97
    _globals["_FIELD"]._serialized_end = 229
    _globals["_UPLOADFILE"]._serialized_start = 231
    _globals["_UPLOADFILE"]._serialized_end = 322
    _globals["_UPLOADXLSXREQUEST"]._serialized_start = 324
    _globals["_UPLOADXLSXREQUEST"]._serialized_end = 418
    _globals["_UPLOADXLSXRESPONSE"]._serialized_start = 421
    _globals["_UPLOADXLSXRESPONSE"]._serialized_end = 587
    _globals["_UPLOADFILESERVICE"]._serialized_start = 590
    _globals["_UPLOADFILESERVICE"]._serialized_end = 751
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock_move.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import picking_pb2 as v1_dot_stock_dot_picking__pb2
from omni.pro.protos.v1.stock import product_pb2 as v1_dot_stock_dot_product__pb2
from omni.pro.protos.v1.stock import uom_pb2 as v1_dot_stock_dot_uom__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/stock/stock_move.proto\x12$pro.omni.oms.api.v1.stock.stock_move\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16v1/stock/picking.proto\x1a\x16v1/stock/product.proto\x1a\x12v1/stock/uom.proto"\x8f\x03\n\tStockMove\x12\n\n\x02id\x18\x01 \x01(\x05\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking\x12\r\n\x05state\x18\x03 \x01(\t\x12;\n\x07product\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product\x12\x15\n\rquantity_done\x18\x05 \x01(\x02\x12\x37\n\x0bproduct_uom\x18\x06 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.uom.Uom\x12\x1b\n\x13\x64\x65scription_picking\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe8\x01\n\x16StockMoveCreateRequest\x12\x12\n\npicking_id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\t\x12\x12\n\nproduct_id\x18\x03 \x01(\t\x12\x15\n\rquantity_done\x18\x04 \x01(\x02\x12\x16\n\x0eproduct_uom_id\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65scription_picking\x18\x06 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17StockMoveCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x43\n\nstock_move\x18\x02 \x01(\x0b\x32/.pro.omni.oms.api.v1.stock.stock_move.StockMove"\xf2\x02\n\x14StockMoveReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n\x15StockMoveReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x44\n\x0bstock_moves\x18\x03 \x03(\x0b\x32/.pro.omni.oms.api.v1.stock.stock_move.StockMove"\x95\x01\n\x16StockMoveUpdateRequest\x12\x43\n\nstock_move\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.stock.stock_move.StockMove\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17StockMoveUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x43\n\nstock_move\x18\x02 \x01(\x0b\x32/.pro.omni.oms.api.v1.stock.stock_move.StockMove"\\\n\x16StockMoveDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17StockMoveDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd8\x04\n\x10StockMoveService\x12\x90\x01\n\x0fStockMoveCreate\x12<.pro.omni.oms.api.v1.stock.stock_move.StockMoveCreateRequest\x1a=.pro.omni.oms.api.v1.stock.stock_move.StockMoveCreateResponse"\x00\x12\x8a\x01\n\rStockMoveRead\x12:.pro.omni.oms.api.v1.stock.stock_move.StockMoveReadRequest\x1a;.pro.omni.oms.api.v1.stock.stock_move.StockMoveReadResponse"\x00\x12\x90\x01\n\x0fStockMoveUpdate\x12<.pro.omni.oms.api.v1.stock.stock_move.StockMoveUpdateRequest\x1a=.pro.omni.oms.api.v1.stock.stock_move.StockMoveUpdateResponse"\x00\x12\x90\x01\n\x0fStockMoveDelete\x12<.pro.omni.oms.api.v1.stock.stock_move.StockMoveDeleteRequest\x1a=.pro.omni.oms.api.v1.stock.stock_move.StockMoveDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_move_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STOCKMOVE"]._serialized_start = 187
    _globals["_STOCKMOVE"]._serialized_end = 586
    _globals["_STOCKMOVECREATEREQUEST"]._serialized_start = 589
    _globals["_STOCKMOVECREATEREQUEST"]._serialized_end = 821
    _globals["_STOCKMOVECREATERESPONSE"]._serialized_start = 824
    _globals["_STOCKMOVECREATERESPONSE"]._serialized_end = 993
    _globals["_STOCKMOVEREADREQUEST"]._serialized_start = 996
    _globals["_STOCKMOVEREADREQUEST"]._serialized_end = 1366
    _globals["_STOCKMOVEREADRESPONSE"]._serialized_start = 1369
    _globals["_STOCKMOVEREADRESPONSE"]._serialized_end = 1596
    _globals["_STOCKMOVEUPDATEREQUEST"]._serialized_start = 1599
    _globals["_STOCKMOVEUPDATEREQUEST"]._serialized_end = 1748
    _globals["_STOCKMOVEUPDATERESPONSE"]._serialized_start = 1751
    _globals["_STOCKMOVEUPDATERESPONSE"]._serialized_end = 1920
    _globals["_STOCKMOVEDELETEREQUEST"]._serialized_start = 1922
    _globals["_STOCKMOVEDELETEREQUEST"]._serialized_end = 2014
    _globals["_STOCKMOVEDELETERESPONSE"]._serialized_start = 2016
    _globals["_STOCKMOVEDELETERESPONSE"]._serialized_end = 2116
    _globals["_STOCKMOVESERVICE"]._serialized_start = 2119
    _globals["_STOCKMOVESERVICE"]._serialized_end = 2719
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/utilities/country.proto\x12%pro.omni.oms.api.v1.utilities.country\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xe0\x04\n\x07\x43ountry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11phone_number_size\x18\x04 \x01(\x05\x12\x14\n\x0cphone_prefix\x18\x05 \x01(\t\x12\x33\n\x0frequire_zipcode\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncurrencies\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x0e\x64ocument_types\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x36\n\x12territory_matrixes\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\tmeta_data\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\ttimezones\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12-\n\tlanguages\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tlow_level\x18\r \x01(\t\x12\x0c\n\x04icon\x18\x0e \x01(\x0c\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x10 \x01(\t\x12?\n\x0cobject_audit\x18\x11 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc0\x04\n\x14\x43ountryCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11phone_number_size\x18\x03 \x01(\x05\x12\x14\n\x0cphone_prefix\x18\x04 \x01(\t\x12\x33\n\x0frequire_zipcode\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x63urrencies_ids\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x36\n\x12\x64ocument_types_ids\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12:\n\x16territory_matrixes_ids\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\tmeta_data\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\rtimezones_ids\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x31\n\rlanguages_ids\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tlow_level\x18\x0c \x01(\t\x12\x0c\n\x04icon\x18\r \x01(\x0c\x12\x13\n\x0b\x65xternal_id\x18\x0e \x01(\t\x12\x36\n\x07\x63ontext\x18\x0f \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15\x43ountryCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07\x63ountry\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"\xf0\x02\n\x12\x43ountryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x13\x43ountryReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x41\n\tcountries\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"\x8f\x01\n\x14\x43ountryUpdateRequest\x12?\n\x07\x63ountry\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15\x43ountryUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07\x63ountry\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"Z\n\x14\x43ountryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43ountryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc6\x04\n\x0e\x43ountryService\x12\x8c\x01\n\rCountryCreate\x12;.pro.omni.oms.api.v1.utilities.country.CountryCreateRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryCreateResponse"\x00\x12\x86\x01\n\x0b\x43ountryRead\x12\x39.pro.omni.oms.api.v1.utilities.country.CountryReadRequest\x1a:.pro.omni.oms.api.v1.utilities.country.CountryReadResponse"\x00\x12\x8c\x01\n\rCountryUpdate\x12;.pro.omni.oms.api.v1.utilities.country.CountryUpdateRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryUpdateResponse"\x00\x12\x8c\x01\n\rCountryDelete\x12;.pro.omni.oms.api.v1.utilities.country.CountryDeleteRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.country_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_COUNTRY"]._serialized_start = 151
    _globals["_COUNTRY"]._serialized_end = 759
    _globals["_COUNTRYCREATEREQUEST"]._serialized_start = 762
    _globals["_COUNTRYCREATEREQUEST"]._serialized_end = 1338
    _globals["_COUNTRYCREATERESPONSE"]._serialized_start = 1341
    _globals["_COUNTRYCREATERESPONSE"]._serialized_end = 1504
    _globals["_COUNTRYREADREQUEST"]._serialized_start = 1507
    _globals["_COUNTRYREADREQUEST"]._serialized_end = 1875
    _globals["_COUNTRYREADRESPONSE"]._serialized_start = 1878
    _globals["_COUNTRYREADRESPONSE"]._serialized_end = 2100
    _globals["_COUNTRYUPDATEREQUEST"]._serialized_start = 2103
    _globals["_COUNTRYUPDATEREQUEST"]._serialized_end = 2246
    _globals["_COUNTRYUPDATERESPONSE"]._serialized_start = 2249
    _globals["_COUNTRYUPDATERESPONSE"]._serialized_end = 2412
    _globals["_COUNTRYDELETEREQUEST"]._serialized_start = 2414
    _globals["_COUNTRYDELETEREQUEST"]._serialized_end = 2504
    _globals["_COUNTRYDELETERESPONSE"]._serialized_start = 2506
    _globals["_COUNTRYDELETERESPONSE"]._serialized_end = 2604
    _globals["_COUNTRYSERVICE"]._serialized_start = 2607
    _globals["_COUNTRYSERVICE"]._serialized_end = 3189
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import event_pb2 as v1_dot_utilities_dot_event__pb2


class EventServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EventCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventCreate",
            request_serializer=v1_dot_utilities_dot_event__pb2.EventCreateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_event__pb2.EventCreateResponse.FromString,
        )
        self.EventRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventRead",
            request_serializer=v1_dot_utilities_dot_event__pb2.EventReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_event__pb2.EventReadResponse.FromString,
        )
        self.EventUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventUpdate",
            request_serializer=v1_dot_utilities_dot_event__pb2.EventUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_event__pb2.EventUpdateResponse.FromString,
        )
        self.EventDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventDelete",
            request_serializer=v1_dot_utilities_dot_event__pb2.EventDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_event__pb2.EventDeleteResponse.FromString,
        )


class EventServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def EventCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EventRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EventUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EventDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "EventCreate": grpc.unary_unary_rpc_method_handler(
            servicer.EventCreate,
            request_deserializer=v1_dot_utilities_dot_event__pb2.EventCreateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_event__pb2.EventCreateResponse.SerializeToString,
        ),
        "EventRead": grpc.unary_unary_rpc_method_handler(
            servicer.EventRead,
            request_deserializer=v1_dot_utilities_dot_event__pb2.EventReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_event__pb2.EventReadResponse.SerializeToString,
        ),
        "EventUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.EventUpdate,
            request_deserializer=v1_dot_utilities_dot_event__pb2.EventUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_event__pb2.EventUpdateResponse.SerializeToString,
        ),
        "EventDelete": grpc.unary_unary_rpc_method_handler(
            servicer.EventDelete,
            request_deserializer=v1_dot_utilities_dot_event__pb2.EventDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_event__pb2.EventDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.event.EventService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class EventService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def EventCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventCreate",
            v1_dot_utilities_dot_event__pb2.EventCreateRequest.SerializeToString,
            v1_dot_utilities_dot_event__pb2.EventCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EventRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventRead",
            v1_dot_utilities_dot_event__pb2.EventReadRequest.SerializeToString,
            v1_dot_utilities_dot_event__pb2.EventReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EventUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventUpdate",
            v1_dot_utilities_dot_event__pb2.EventUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_event__pb2.EventUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EventDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.event.EventService/EventDelete",
            v1_dot_utilities_dot_event__pb2.EventDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_event__pb2.EventDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/catalogs/family.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/catalogs/family.proto\x12#pro.omni.oms.api.v1.catalogs.family\x1a\x1cgoogle/protobuf/struct.proto\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x9e\x03\n\x06\x46\x61mily\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12J\n\x12\x61ttribute_as_label\x18\x04 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute\x12J\n\x12\x61ttribute_as_image\x18\x05 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute\x12)\n\x08variants\x18\x06 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06groups\x18\x07 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb6\x01\n\x13\x46\x61milyCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1a\n\x12\x61ttribute_as_label\x18\x03 \x01(\t\x12\x1a\n\x12\x61ttribute_as_image\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9e\x01\n\x14\x46\x61milyCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x06\x66\x61mily\x18\x02 \x01(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family"\xef\x02\n\x11\x46\x61milyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x02\n\x12\x46\x61milyReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12=\n\x08\x66\x61milies\x18\x03 \x03(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8a\x01\n\x13\x46\x61milyUpdateRequest\x12;\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9e\x01\n\x14\x46\x61milyUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x06\x66\x61mily\x18\x02 \x01(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family"Y\n\x13\x46\x61milyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x46\x61milyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x96\x02\n\tAttribute\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\x12\x11\n\tis_common\x18\x04 \x01(\x08\x12\'\n\x06\x66\x61mily\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05group\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12\x30\n\x0f\x65xtra_attribute\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct"\x85\x02\n\x16\x41ttributeCreateRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x12\n\ngroup_code\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x05 \x01(\t\x12\x11\n\tis_common\x18\x06 \x01(\x08\x12\x30\n\x0f\x65xtra_attribute\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12\x36\n\x07\x63ontext\x18\t \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17\x41ttributeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\tattribute\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute"\x9b\x03\n\x14\x41ttributeReadRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x12\n\ngroup_code\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x37\n\x08group_by\x18\x04 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x05 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x06 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x07 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x08 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\t \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x15\x41ttributeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x42\n\nattributes\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute"\x93\x01\n\x16\x41ttributeUpdateRequest\x12\x41\n\tattribute\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17\x41ttributeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\tattribute\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute"\x85\x01\n\x16\x41ttributeDeleteRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x12\n\ngroup_code\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17\x41ttributeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xd1\x01\n\x05Group\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x06\x61\x63tive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x06\x66\x61mily\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x42\n\nattributes\x18\x06 \x03(\x0b\x32..pro.omni.oms.api.v1.catalogs.family.Attribute"\x90\x01\n\x12GroupCreateRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13GroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05group\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.catalogs.family.Group"\x83\x03\n\x10GroupReadRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x37\n\x08group_by\x18\x03 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x05 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x06 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x07 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x11GroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12:\n\x06groups\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.catalogs.family.Group"\x9a\x01\n\x12GroupUpdateRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x39\n\x05group\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.catalogs.family.Group\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13GroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05group\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.catalogs.family.Group"m\n\x12GroupDeleteRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13GroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa4\x01\n\x10\x41ttributeVariant\x12*\n\tattribute\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12\x11\n\tfamily_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xa9\x01\n\x1d\x41ttributeVariantCreateRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1e\x41ttributeVariantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x11\x61ttribute_variant\x18\x02 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.catalogs.family.AttributeVariant"\x98\x03\n\x1b\x41ttributeVariantReadRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x02 \x01(\t\x12\x37\n\x08group_by\x18\x03 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x05 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x06 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x07 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x1c\x41ttributeVariantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12Q\n\x12\x61ttribute_variants\x18\x03 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.catalogs.family.AttributeVariant"\xb7\x01\n\x1d\x41ttributeVariantUpdateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12P\n\x11\x61ttribute_variant\x18\x02 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.catalogs.family.AttributeVariant\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1e\x41ttributeVariantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x11\x61ttribute_variant\x18\x02 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.catalogs.family.AttributeVariant"\x82\x01\n\x1d\x41ttributeVariantDeleteRequest\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1e\x41ttributeVariantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xaf\x01\n\x08\x43\x61tegory\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\x12\x11\n\tis_common\x18\x04 \x01(\x08\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0f\x65xtra_attribute\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct"\xe5\x02\n\x13\x43\x61tegoryReadRequest\x12\x37\n\x08group_by\x18\x02 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x05 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x06 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdf\x01\n\x14\x43\x61tegoryReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x41\n\ncategories\x18\x03 \x03(\x0b\x32-.pro.omni.oms.api.v1.catalogs.family.Category2\x8d\x13\n\rFamilyService\x12\x85\x01\n\x0c\x46\x61milyCreate\x12\x38.pro.omni.oms.api.v1.catalogs.family.FamilyCreateRequest\x1a\x39.pro.omni.oms.api.v1.catalogs.family.FamilyCreateResponse"\x00\x12\x7f\n\nFamilyRead\x12\x36.pro.omni.oms.api.v1.catalogs.family.FamilyReadRequest\x1a\x37.pro.omni.oms.api.v1.catalogs.family.FamilyReadResponse"\x00\x12\x85\x01\n\x0c\x46\x61milyUpdate\x12\x38.pro.omni.oms.api.v1.catalogs.family.FamilyUpdateRequest\x1a\x39.pro.omni.oms.api.v1.catalogs.family.FamilyUpdateResponse"\x00\x12\x85\x01\n\x0c\x46\x61milyDelete\x12\x38.pro.omni.oms.api.v1.catalogs.family.FamilyDeleteRequest\x1a\x39.pro.omni.oms.api.v1.catalogs.family.FamilyDeleteResponse"\x00\x12\x82\x01\n\x0bGroupCreate\x12\x37.pro.omni.oms.api.v1.catalogs.family.GroupCreateRequest\x1a\x38.pro.omni.oms.api.v1.catalogs.family.GroupCreateResponse"\x00\x12|\n\tGroupRead\x12\x35.pro.omni.oms.api.v1.catalogs.family.GroupReadRequest\x1a\x36.pro.omni.oms.api.v1.catalogs.family.GroupReadResponse"\x00\x12\x82\x01\n\x0bGroupUpdate\x12\x37.pro.omni.oms.api.v1.catalogs.family.GroupUpdateRequest\x1a\x38.pro.omni.oms.api.v1.catalogs.family.GroupUpdateResponse"\x00\x12\x82\x01\n\x0bGroupDelete\x12\x37.pro.omni.oms.api.v1.catalogs.family.GroupDeleteRequest\x1a\x38.pro.omni.oms.api.v1.catalogs.family.GroupDeleteResponse"\x00\x12\x8e\x01\n\x0f\x41ttributeCreate\x12;.pro.omni.oms.api.v1.catalogs.family.AttributeCreateRequest\x1a<.pro.omni.oms.api.v1.catalogs.family.AttributeCreateResponse"\x00\x12\x88\x01\n\rAttributeRead\x12\x39.pro.omni.oms.api.v1.catalogs.family.AttributeReadRequest\x1a:.pro.omni.oms.api.v1.catalogs.family.AttributeReadResponse"\x00\x12\x8e\x01\n\x0f\x41ttributeUpdate\x12;.pro.omni.oms.api.v1.catalogs.family.AttributeUpdateRequest\x1a<.pro.omni.oms.api.v1.catalogs.family.AttributeUpdateResponse"\x00\x12\x8e\x01\n\x0f\x41ttributeDelete\x12;.pro.omni.oms.api.v1.catalogs.family.AttributeDeleteRequest\x1a<.pro.omni.oms.api.v1.catalogs.family.AttributeDeleteResponse"\x00\x12\xa3\x01\n\x16\x41ttributeVariantCreate\x12\x42.pro.omni.oms.api.v1.catalogs.family.AttributeVariantCreateRequest\x1a\x43.pro.omni.oms.api.v1.catalogs.family.AttributeVariantCreateResponse"\x00\x12\x9d\x01\n\x14\x41ttributeVariantRead\x12@.pro.omni.oms.api.v1.catalogs.family.AttributeVariantReadRequest\x1a\x41.pro.omni.oms.api.v1.catalogs.family.AttributeVariantReadResponse"\x00\x12\xa3\x01\n\x16\x41ttributeVariantUpdate\x12\x42.pro.omni.oms.api.v1.catalogs.family.AttributeVariantUpdateRequest\x1a\x43.pro.omni.oms.api.v1.catalogs.family.AttributeVariantUpdateResponse"\x00\x12\xa3\x01\n\x16\x41ttributeVariantDelete\x12\x42.pro.omni.oms.api.v1.catalogs.family.AttributeVariantDeleteRequest\x1a\x43.pro.omni.oms.api.v1.catalogs.family.AttributeVariantDeleteResponse"\x00\x12\x85\x01\n\x0c\x43\x61tegoryRead\x12\x38.pro.omni.oms.api.v1.catalogs.family.CategoryReadRequest\x1a\x39.pro.omni.oms.api.v1.catalogs.family.CategoryReadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.catalogs.family_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_FAMILY"]._serialized_start = 147
    _globals["_FAMILY"]._serialized_end = 561
    _globals["_FAMILYCREATEREQUEST"]._serialized_start = 564
    _globals["_FAMILYCREATEREQUEST"]._serialized_end = 746
    _globals["_FAMILYCREATERESPONSE"]._serialized_start = 749
    _globals["_FAMILYCREATERESPONSE"]._serialized_end = 907
    _globals["_FAMILYREADREQUEST"]._serialized_start = 910
    _globals["_FAMILYREADREQUEST"]._serialized_end = 1277
    _globals["_FAMILYREADRESPONSE"]._serialized_start = 1280
    _globals["_FAMILYREADRESPONSE"]._serialized_end = 1553
    _globals["_FAMILYUPDATEREQUEST"]._serialized_start = 1556
    _globals["_FAMILYUPDATEREQUEST"]._serialized_end = 1694
    _globals["_FAMILYUPDATERESPONSE"]._serialized_start = 1697
    _globals["_FAMILYUPDATERESPONSE"]._serialized_end = 1855
    _globals["_FAMILYDELETEREQUEST"]._serialized_start = 1857
    _globals["_FAMILYDELETEREQUEST"]._serialized_end = 1946
    _globals["_FAMILYDELETERESPONSE"]._serialized_start = 1948
    _globals["_FAMILYDELETERESPONSE"]._serialized_end = 2045
    _globals["_ATTRIBUTE"]._serialized_start = 2048
    _globals["_ATTRIBUTE"]._serialized_end = 2326
    _globals["_ATTRIBUTECREATEREQUEST"]._serialized_start = 2329
    _globals["_ATTRIBUTECREATEREQUEST"]._serialized_end = 2590
    _globals["_ATTRIBUTECREATERESPONSE"]._serialized_start = 2593
    _globals["_ATTRIBUTECREATERESPONSE"]._serialized_end = 2760
    _globals["_ATTRIBUTEREADREQUEST"]._serialized_start = 2763
    _globals["_ATTRIBUTEREADREQUEST"]._serialized_end = 3174
    _globals["_ATTRIBUTEREADRESPONSE"]._serialized_start = 3177
    _globals["_ATTRIBUTEREADRESPONSE"]._serialized_end = 3402
    _globals["_ATTRIBUTEUPDATEREQUEST"]._serialized_start = 3405
    _globals["_ATTRIBUTEUPDATEREQUEST"]._serialized_end = 3552
    _globals["_ATTRIBUTEUPDATERESPONSE"]._serialized_start = 3555
    _globals["_ATTRIBUTEUPDATERESPONSE"]._serialized_end = 3722
    _globals["_ATTRIBUTEDELETEREQUEST"]._serialized_start = 3725
    _globals["_ATTRIBUTEDELETEREQUEST"]._serialized_end = 3858
    _globals["_ATTRIBUTEDELETERESPONSE"]._serialized_start = 3860
    _globals["_ATTRIBUTEDELETERESPONSE"]._serialized_end = 3960
    _globals["_GROUP"]._serialized_start = 3963
    _globals["_GROUP"]._serialized_end = 4172
    _globals["_GROUPCREATEREQUEST"]._serialized_start = 4175
    _globals["_GROUPCREATEREQUEST"]._serialized_end = 4319
    _globals["_GROUPCREATERESPONSE"]._serialized_start = 4322
    _globals["_GROUPCREATERESPONSE"]._serialized_end = 4477
    _globals["_GROUPREADREQUEST"]._serialized_start = 4480
    _globals["_GROUPREADREQUEST"]._serialized_end = 4867
    _globals["_GROUPREADRESPONSE"]._serialized_start = 4870
    _globals["_GROUPREADRESPONSE"]._serialized_end = 5083
    _globals["_GROUPUPDATEREQUEST"]._serialized_start = 5086
    _globals["_GROUPUPDATEREQUEST"]._serialized_end = 5240
    _globals["_GROUPUPDATERESPONSE"]._serialized_start = 5243
    _globals["_GROUPUPDATERESPONSE"]._serialized_end = 5398
    _globals["_GROUPDELETEREQUEST"]._serialized_start = 5400
    _globals["_GROUPDELETEREQUEST"]._serialized_end = 5509
    _globals["_GROUPDELETERESPONSE"]._serialized_start = 5511
    _globals["_GROUPDELETERESPONSE"]._serialized_end = 5607
    _globals["_ATTRIBUTEVARIANT"]._serialized_start = 5610
    _globals["_ATTRIBUTEVARIANT"]._serialized_end = 5774
    _globals["_ATTRIBUTEVARIANTCREATEREQUEST"]._serialized_start = 5777
    _globals["_ATTRIBUTEVARIANTCREATEREQUEST"]._serialized_end = 5946
    _globals["_ATTRIBUTEVARIANTCREATERESPONSE"]._serialized_start = 5949
    _globals["_ATTRIBUTEVARIANTCREATERESPONSE"]._serialized_end = 6138
    _globals["_ATTRIBUTEVARIANTREADREQUEST"]._serialized_start = 6141
    _globals["_ATTRIBUTEVARIANTREADREQUEST"]._serialized_end = 6549
    _globals["_ATTRIBUTEVARIANTREADRESPONSE"]._serialized_start = 6552
    _globals["_ATTRIBUTEVARIANTREADRESPONSE"]._serialized_end = 6799
    _globals["_ATTRIBUTEVARIANTUPDATEREQUEST"]._serialized_start = 6802
    _globals["_ATTRIBUTEVARIANTUPDATEREQUEST"]._serialized_end = 6985
    _globals["_ATTRIBUTEVARIANTUPDATERESPONSE"]._serialized_start = 6988
    _globals["_ATTRIBUTEVARIANTUPDATERESPONSE"]._serialized_end = 7177
    _globals["_ATTRIBUTEVARIANTDELETEREQUEST"]._serialized_start = 7180
    _globals["_ATTRIBUTEVARIANTDELETEREQUEST"]._serialized_end = 7310
    _globals["_ATTRIBUTEVARIANTDELETERESPONSE"]._serialized_start = 7312
    _globals["_ATTRIBUTEVARIANTDELETERESPONSE"]._serialized_end = 7419
    _globals["_CATEGORY"]._serialized_start = 7422
    _globals["_CATEGORY"]._serialized_end = 7597
    _globals["_CATEGORYREADREQUEST"]._serialized_start = 7600
    _globals["_CATEGORYREADREQUEST"]._serialized_end = 7957
    _globals["_CATEGORYREADRESPONSE"]._serialized_start = 7960
    _globals["_CATEGORYREADRESPONSE"]._serialized_end = 8183
    _globals["_FAMILYSERVICE"]._serialized_start = 8186
    _globals["_FAMILYSERVICE"]._serialized_end = 10631
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/import_export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/import_export.proto\x12+pro.omni.oms.api.v1.utilities.import_export\x1a\x11\x63ommon/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/model.proto"\xc1\x03\n\x0cImportExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05micro\x18\x02 \x01(\t\x12\x16\n\x0etype_operation\x18\x03 \x01(\t\x12\x39\n\x05model\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x11\n\tname_file\x18\x05 \x01(\t\x12\x11\n\ttype_file\x18\x06 \x01(\t\x12-\n\tdate_load\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12.\n\nskip_error\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe4\x02\n\x19ImportExportCreateRequest\x12\r\n\x05micro\x18\x01 \x01(\t\x12\x16\n\x0etype_operation\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x11\n\tname_file\x18\x04 \x01(\t\x12\x11\n\ttype_file\x18\x05 \x01(\t\x12-\n\tdate_load\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12.\n\nskip_error\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xf5\x02\n\x17ImportExportReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf2\x01\n\x18ImportExportReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12P\n\rimport_export\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xa5\x01\n\x19ImportExportUpdateRequest\x12P\n\rimport_export\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"_\n\x19ImportExportDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport2\xb7\x05\n\x13ImportExportService\x12\xa7\x01\n\x12ImportExportCreate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateResponse"\x00\x12\xa1\x01\n\x10ImportExportRead\x12\x44.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadResponse"\x00\x12\xa7\x01\n\x12ImportExportUpdate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateResponse"\x00\x12\xa7\x01\n\x12ImportExportDelete\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.import_export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_IMPORTEXPORT"]._serialized_start = 192
    _globals["_IMPORTEXPORT"]._serialized_end = 641
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_start = 644
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_end = 1000
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_start = 1003
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_end = 1188
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_start = 1191
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_end = 1564
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_start = 1567
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_end = 1809
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_start = 1812
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_end = 1977
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_start = 1980
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_end = 2165
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_start = 2167
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_end = 2262
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_start = 2265
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_end = 2450
    _globals["_IMPORTEXPORTSERVICE"]._serialized_start = 2453
    _globals["_IMPORTEXPORTSERVICE"]._serialized_end = 3148
# @@protoc_insertion_point(module_scope)
